@@ -161,7 +161,7 @@ def save_config_py(config_: dict, path: str) -> NoReturn:
 def read_config_directly(path: str) -> dict:
     """
     Overview:
-        Read configuration from a file path(now only suport python file) and directly return results.
+        Read configuration from a file path(now only support python file) and directly return results.
     Arguments:
         - path (:obj:`str`): Path of configuration file
     Returns:
@@ -372,6 +372,8 @@ def compile_config(
         policy_config = deep_merge_dicts(policy_config_template, policy_config)
         policy_config.update(create_cfg.policy)
         policy_config.collect.collector.update(create_cfg.collector)
+        if 'evaluator' in create_cfg:
+            policy_config.eval.evaluator.update(create_cfg.evaluator)
         policy_config.other.replay_buffer.update(create_cfg.replay_buffer)
 
         policy_config.other.commander = BaseSerialCommander.default_config()
