@@ -1,5 +1,5 @@
 from .common_function import num_first_one_hot, sqrt_one_hot, div_one_hot, div_func, clip_one_hot, \
-    reorder_one_hot, reorder_one_hot_array, reorder_boolean_vector, \
+    reorder_one_hot, reorder_one_hot_array, reorder_boolean_vector, affine_transform, \
     batch_binary_encode, get_postion_vector
-from .env_element import EnvElement
+from .env_element import EnvElement, EnvElementInfo
 from .env_element_runner import EnvElementRunner
