@@ -9,7 +9,12 @@ from ding.utils import import_module, ENV_REGISTRY
 BaseEnvTimestep = namedtuple('BaseEnvTimestep', ['obs', 'reward', 'done', 'info'])
 
 
-class BaseEnv(ABC, gym.Env):
+# for solving multiple inheritance metaclass conflict between gym and ABC
+class FinalMeta(type(gym.Env), type(ABC)):
+    pass
+
+
+class BaseEnv(gym.Env, ABC, metaclass=FinalMeta):
     """
     Overview:
         Basic environment class, extended from ``gym.Env``
