@@ -1,23 +1,24 @@
 from typing import Any, Union, List, Tuple, Dict, Callable, Optional
 from multiprocessing import Pipe, connection, get_context, Array
 from collections import namedtuple
-import logging
+from ditk import logging
 import platform
 import time
 import copy
+import gym
 import traceback
-import numpy as np
 import torch
 import ctypes
 import pickle
 import cloudpickle
+import numpy as np
+import treetensor.numpy as tnp
 from easydict import EasyDict
 from types import MethodType
 
-from ding.utils import PropagatingThread, LockContextType, LockContext, ENV_MANAGER_REGISTRY
+from ding.envs.env import BaseEnvTimestep
+from ding.utils import PropagatingThread, LockContextType, LockContext, ENV_MANAGER_REGISTRY, make_key_as_identifier
 from .base_env_manager import BaseEnvManager, EnvState, timeout_wrapper
-from ding.envs.env.base_env import BaseEnvTimestep
-import gym
 
 _NTYPE_TO_CTYPE = {
     np.bool_: ctypes.c_bool,
@@ -319,6 +320,22 @@ class AsyncSubprocessEnvManager(BaseEnvManager):
             sleep_count += 1
         return {i: self._ready_obs[i] for i in self.ready_env}
 
+    @property
+    def ready_imgs(self, render_mode: Optional[str] = 'rgb_array') -> Dict[int, Any]:
+        """
+        Overview:
+            Get the next renderd frames.
+        Return:
+            A dictionary with rendered frames and their environment IDs.
+        Note:
+            The rendered frames are returned in np.ndarray.
+        """
+        for i in self.ready_env:
+            self._pipe_parents[i].send(['render', None, {'render_mode': render_mode}])
+        data = {i: self._pipe_parents[i].recv() for i in self.ready_env}
+        self._check_data(data)
+        return data
+
     def launch(self, reset_param: Optional[Dict] = None) -> None:
         """
         Overview:
@@ -672,6 +689,9 @@ class AsyncSubprocessEnvManager(BaseEnvManager):
                         if kwargs is None:
                             kwargs = {}
                         ret = reset_fn(*args, **kwargs)
+                    elif cmd == 'render':
+                        from ding.utils import render
+                        ret = render(env, **kwargs)
                     elif args is None and kwargs is None:
                         ret = getattr(env, cmd)()
                     else:
@@ -882,3 +902,56 @@ class SyncSubprocessEnvManager(AsyncSubprocessEnvManager):
             else:
                 self._ready_obs[env_id] = timestep.obs
         return timesteps
+
+
+@ENV_MANAGER_REGISTRY.register('subprocess_v2')
+class SubprocessEnvManagerV2(SyncSubprocessEnvManager):
+    """
+    Overview:
+        SyncSubprocessEnvManager for new task pipeline and interfaces coupled with treetensor.
+    """
+
+    @property
+    def ready_obs(self) -> tnp.array:
+        """
+        Overview:
+            Get the ready (next) observation in ``tnp.array`` type, which is uniform for both async/sync scenarios.
+        Return:
+            - ready_obs (:obj:`tnp.array`): A stacked treenumpy-type observation data.
+        Example:
+            >>> obs = env_manager.ready_obs
+            >>> action = model(obs)  # model input np obs and output np action
+            >>> timesteps = env_manager.step(action)
+        """
+        no_done_env_idx = [i for i, s in self._env_states.items() if s != EnvState.DONE]
+        sleep_count = 0
+        while not any([self._env_states[i] == EnvState.RUN for i in no_done_env_idx]):
+            if sleep_count % 1000 == 0:
+                logging.warning(
+                    'VEC_ENV_MANAGER: all the not done envs are resetting, sleep {} times'.format(sleep_count)
+                )
+            time.sleep(0.001)
+            sleep_count += 1
+        obs = [self._ready_obs[i] for i in self.ready_env]
+        return tnp.stack(obs)
+
+    def step(self, actions: List[tnp.ndarray]) -> List[tnp.ndarray]:
+        """
+        Overview:
+            Execute env step according to input actions. And reset an env if done.
+        Arguments:
+            - actions (:obj:`List[tnp.ndarray]`): actions came from outer caller like policy
+        Returns:
+            - timesteps (:obj:`List[tnp.ndarray]`): Each timestep is a tnp.array with observation, reward, done, \
+                info, env_id.
+        """
+        actions = {env_id: a for env_id, a in zip(self.ready_obs_id, actions)}
+        timesteps = super().step(actions)
+        new_data = []
+        for env_id, timestep in timesteps.items():
+            obs, reward, done, info = timestep
+            # make the type and content of key as similar as identifier,
+            # in order to call them as attribute (e.g. timestep.xxx), such as ``TimeLimit.truncated`` in cartpole info
+            info = make_key_as_identifier(info)
+            new_data.append(tnp.array({'obs': obs, 'reward': reward, 'done': done, 'info': info, 'env_id': env_id}))
+        return new_data
