@@ -4,7 +4,7 @@ from .data_processor import offpolicy_data_fetcher, data_pusher, offline_data_fe
 from .collector import inferencer, rolloutor, TransitionList
 from .evaluator import interaction_evaluator
 from .termination_checker import termination_checker
-from .pace_controller import pace_controller
+from .ctx_helper import final_ctx_saver
 
 # algorithm
 from .explorer import eps_greedy_handler, eps_greedy_masker
