@@ -1,9 +1,9 @@
 # general
-from .q_learning import DQN, RainbowDQN, QRDQN, IQN, DRQN, C51DQN
+from .q_learning import DQN, RainbowDQN, QRDQN, IQN, FQF, DRQN, C51DQN
 from .qac import QAC, DiscreteQAC
 from .pdqn import PDQN
 from .vac import VAC
-from .bc import BC
+from .bc import DiscreteBC, ContinuousBC
 # algorithm-specific
 from .ppg import PPG
 from .qmix import Mixer, QMix, CollaQ
@@ -17,5 +17,5 @@ from .mavac import MAVAC
 from .ngu import NGU
 from .qac_dist import QACDIST
 from .maqac import MAQAC, ContinuousMAQAC
-from .model_based import EnsembleDynamicsModel
 from .vae import VanillaVAE
+from .decision_transformer import DecisionTransformer
