@@ -1,20 +1,19 @@
 import math
 import torch
 import torch.nn as nn
-import copy
-from torch.optim import Adam
-from torch.optim.lr_scheduler import LambdaLR
+import logging
+from torch.optim import Adam, AdamW
 from typing import List, Dict, Any, Tuple, Union, Optional
-from collections import namedtuple, deque
+from collections import namedtuple
 from easydict import EasyDict
 from ding.policy import Policy
 from ding.model import model_wrap
-from ding.torch_utils import to_device
+from ding.torch_utils import to_device, to_list
 from ding.utils import EasyTimer
 from ding.utils.data import default_collate, default_decollate
-from ding.rl_utils import q_nstep_td_data, q_nstep_sql_td_error, get_nstep_return_data, get_train_sample
-from ding.worker.collector.interaction_serial_evaluator import InteractionSerialEvaluator
+from ding.rl_utils import get_nstep_return_data, get_train_sample
 from ding.utils import POLICY_REGISTRY
+from ding.torch_utils.loss.cross_entropy_loss import LabelSmoothCELoss
 
 
 @POLICY_REGISTRY.register('bc')
@@ -31,11 +30,15 @@ class BehaviourCloningPolicy(Policy):
         cuda=False,
         on_policy=False,
         continuous=False,
+        action_shape=19,
         learn=dict(
             multi_gpu=False,
             update_per_collect=1,
             batch_size=32,
             learning_rate=1e-5,
+            weight_decay=None,
+            ce_label_smooth=False,
+            show_accuracy=False,
         ),
         collect=dict(unroll_len=1, ),
         eval=dict(),
@@ -43,13 +46,20 @@ class BehaviourCloningPolicy(Policy):
     )
 
     def _init_learn(self):
-        self._optimizer = Adam(
-            self._model.parameters(),
-            lr=self._cfg.learn.learning_rate,
-        )
+        if self._cfg.learn.weight_decay is None:
+            self._optimizer = Adam(
+                self._model.parameters(),
+                lr=self._cfg.learn.learning_rate,
+            )
+        else:
+            self._optimizer = AdamW(
+                self._model.parameters(), lr=self._cfg.learn.learning_rate, weight_decay=self._cfg.learn.weight_decay
+            )
+
         self._timer = EasyTimer(cuda=True)
         self._learn_model = model_wrap(self._model, 'base')
         self._learn_model.reset()
+
         if self._cfg.continuous:
             if self._cfg.loss_type == 'l1_loss':
                 self._loss = nn.L1Loss()
@@ -58,7 +68,15 @@ class BehaviourCloningPolicy(Policy):
             else:
                 raise KeyError
         else:
-            self._loss = nn.CrossEntropyLoss()
+            if not self._cfg.learn.ce_label_smooth:
+                self._loss = nn.CrossEntropyLoss()
+            else:
+                self._loss = LabelSmoothCELoss(0.1)
+
+            if self._cfg.learn.show_accuracy:
+                # accuracy statistics for debugging in discrete action space env, e.g. for gfootball
+                self.total_accuracy_in_dataset = []
+                self.action_accuracy_in_dataset = {k: [] for k in range(self._cfg.action_shape)}
 
     def _forward_learn(self, data):
         if not isinstance(data, dict):
@@ -77,6 +95,25 @@ class BehaviourCloningPolicy(Policy):
             else:
                 a_logit = self._learn_model.forward(obs)
                 loss = self._loss(a_logit['logit'], action)
+
+                if self._cfg.learn.show_accuracy:
+                    # Calculate the overall accuracy and the accuracy of each class
+                    total_accuracy = (a_logit['action'] == action.view(-1)).float().mean()
+                    self.total_accuracy_in_dataset.append(total_accuracy)
+                    logging.info(f'the total accuracy in current train mini-batch is: {total_accuracy.item()}')
+                    for action_unique in to_list(torch.unique(action)):
+                        action_index = (action == action_unique).nonzero(as_tuple=True)[0]
+                        action_accuracy = (a_logit['action'][action_index] == action.view(-1)[action_index]
+                                           ).float().mean()
+                        if math.isnan(action_accuracy):
+                            action_accuracy = 0.0
+                        self.action_accuracy_in_dataset[action_unique].append(action_accuracy)
+                        logging.info(
+                            f'the accuracy of action {action_unique} in current train mini-batch is: '
+                            f'{action_accuracy.item()}, '
+                            f'(nan means the action does not appear in the mini-batch)'
+                        )
+
         forward_time = self._timer.value
         with self._timer:
             self._optimizer.zero_grad()
@@ -108,11 +145,17 @@ class BehaviourCloningPolicy(Policy):
         self._eval_model.reset()
 
     def _forward_eval(self, data):
+        gfootball_flag = False
         tensor_input = isinstance(data, torch.Tensor)
         if tensor_input:
             data = default_collate(list(data))
         else:
             data_id = list(data.keys())
+            if data_id == ['processed_obs', 'raw_obs']:
+                # for gfootball
+                gfootball_flag = True
+                data = {0: data}
+                data_id = list(data.keys())
             data = default_collate(list(data.values()))
         if self._cuda:
             data = to_device(data, self._device)
@@ -121,7 +164,7 @@ class BehaviourCloningPolicy(Policy):
             output = self._eval_model.forward(data)
         if self._cuda:
             output = to_device(output, 'cpu')
-        if tensor_input:
+        if tensor_input or gfootball_flag:
             return output
         else:
             output = default_decollate(output)
