@@ -4,8 +4,8 @@ import torch
 import copy
 
 from ding.torch_utils import Adam, to_device
-from ding.rl_utils import q_nstep_td_data, q_nstep_td_error, q_nstep_td_error_with_rescale, q_nstep_td_error_ngu, \
-    q_nstep_td_error_with_rescale_ngu, get_nstep_return_data, get_train_sample
+from ding.rl_utils import q_nstep_td_data, q_nstep_td_error, q_nstep_td_error_with_rescale, get_nstep_return_data, \
+    get_train_sample
 from ding.model import model_wrap
 from ding.utils import POLICY_REGISTRY
 from ding.utils.data import timestep_collate, default_collate, default_decollate
@@ -16,7 +16,7 @@ from .base_policy import Policy
 class NGUPolicy(Policy):
     r"""
     Overview:
-        Policy class of NGU, from paper `never give up: learning directed exploration strategies` .
+        Policy class of NGU. The corresponding paper is `never give up: learning directed exploration strategies`.
 
     Config:
         == ==================== ======== ============== ======================================== =======================
@@ -80,9 +80,10 @@ class NGUPolicy(Policy):
         # (int) the timestep of burnin operation, which is designed to RNN hidden state difference
         # caused by off-policy
         burnin_step=20,
-        # (int) the trajectory length to unroll the RNN network minus
-        # the timestep of burnin operation
-        unroll_len=80,
+        # (int) <learn_unroll_len> is the total length of [sequence sample] minus
+        # the length of burnin part in [sequence sample],
+        # i.e., <sequence sample length> = <unroll_len> = <burnin_step> + <learn_unroll_len>
+        learn_unroll_len=80,  # set this key according to the episode length
         learn=dict(
             # (bool) Whether to use multi gpu
             multi_gpu=False,
@@ -92,16 +93,22 @@ class NGUPolicy(Policy):
             # ==============================================================
             # The following configs are algorithm-specific
             # ==============================================================
-            # (int) Frequence of target network update.
-            # target_update_freq=100,
+            # (float type) target_update_theta: Used for soft update of the target network,
+            # aka. Interpolation factor in polyak averaging for target networks.
             target_update_theta=0.001,
             # (bool) whether use value_rescale function for predicted value
             value_rescale=True,
             ignore_done=False,
         ),
         collect=dict(
-            # NOTE it is important that don't include key n_sample here, to make sure self._traj_len=INF
-            # each_iter_n_sample=32,
+            # NOTE: It is important that set key traj_len_inf=True here,
+            # to make sure self._traj_len=INF in serial_sample_collector.py.
+            # In sequence-based policy, for each collect_env,
+            # we want to collect data of length self._traj_len=INF
+            # unless the episode enters the 'done' state.
+            # In each collect phase, we collect a total of <n_sample> sequence samples.
+            n_sample=32,
+            traj_len_inf=True,
             # `env_num` is used in hidden state, should equal to that one in env config.
             # User should specify this value in user config.
             env_num=None,
@@ -199,25 +206,25 @@ class NGUPolicy(Policy):
         bs = self._burnin_step
 
         # data['done'], data['weight'], data['value_gamma'] is used in def _forward_learn() to calculate
-        # the q_nstep_td_error, should be length of [self._unroll_len_add_burnin_step-self._burnin_step]
+        # the q_nstep_td_error, should be length of [self._sequence_len-self._burnin_step]
         ignore_done = self._cfg.learn.ignore_done
         if ignore_done:
-            data['done'] = [None for _ in range(self._unroll_len_add_burnin_step - bs - self._nstep)]
+            data['done'] = [None for _ in range(self._sequence_len - bs - self._nstep)]
         else:
             data['done'] = data['done'][bs:].float()  # for computation of online model self._learn_model
             # NOTE that after the proprocessing of  get_nstep_return_data() in _get_train_sample
             # the data['done'] [t] is already the n-step done
 
         # if the data don't include 'weight' or 'value_gamma' then fill in None in a list
-        # with length of [self._unroll_len_add_burnin_step-self._burnin_step],
+        # with length of [self._sequence_len-self._burnin_step],
         # below is two different implementation ways
         if 'value_gamma' not in data:
-            data['value_gamma'] = [None for _ in range(self._unroll_len_add_burnin_step - bs)]
+            data['value_gamma'] = [None for _ in range(self._sequence_len - bs)]
         else:
             data['value_gamma'] = data['value_gamma'][bs:]
 
         if 'weight' not in data:
-            data['weight'] = [None for _ in range(self._unroll_len_add_burnin_step - bs)]
+            data['weight'] = [None for _ in range(self._sequence_len - bs)]
         else:
             data['weight'] = data['weight'] * torch.ones_like(data['done'])
             # every timestep in sequence has same weight, which is the _priority_IS_weight in PER
@@ -285,10 +292,10 @@ class NGUPolicy(Policy):
                     'enable_fast_timestep': True
                 }
                 tmp = self._learn_model.forward(
-                    inputs, saved_hidden_state_timesteps=[self._burnin_step, self._burnin_step + self._nstep]
+                    inputs, saved_state_timesteps=[self._burnin_step, self._burnin_step + self._nstep]
                 )
                 tmp_target = self._target_model.forward(
-                    inputs, saved_hidden_state_timesteps=[self._burnin_step, self._burnin_step + self._nstep]
+                    inputs, saved_state_timesteps=[self._burnin_step, self._burnin_step + self._nstep]
                 )
 
         inputs = {
@@ -298,11 +305,11 @@ class NGUPolicy(Policy):
             'beta': data['main_beta'],
             'enable_fast_timestep': True
         }
-        self._learn_model.reset(data_id=None, state=tmp['saved_hidden_state'][0])
+        self._learn_model.reset(data_id=None, state=tmp['saved_state'][0])
         q_value = self._learn_model.forward(inputs)['logit']
 
-        self._learn_model.reset(data_id=None, state=tmp['saved_hidden_state'][1])
-        self._target_model.reset(data_id=None, state=tmp_target['saved_hidden_state'][1])
+        self._learn_model.reset(data_id=None, state=tmp['saved_state'][1])
+        self._target_model.reset(data_id=None, state=tmp_target['saved_state'][1])
 
         next_inputs = {
             'obs': data['target_obs'],
@@ -318,28 +325,28 @@ class NGUPolicy(Policy):
 
         action, reward, done, weight = data['action'], data['reward'], data['done'], data['weight']
         value_gamma = [
-            None for _ in range(self._unroll_len_add_burnin_step - self._burnin_step)
+            None for _ in range(self._sequence_len - self._burnin_step)
         ]  # NOTE this is important, because we use diffrent gamma according to their beta in NGU alg.
 
         # T, B, nstep -> T, nstep, B
         reward = reward.permute(0, 2, 1).contiguous()
         loss = []
         td_error = []
-        self._gamma = [self.index_to_gamma[int(i)] for i in data['main_beta'][0]]  # T, B -> B, 75,64 -> 64
+        self._gamma = [self.index_to_gamma[int(i)] for i in data['main_beta'][0]]  # T, B -> B, e.g. 75,64 -> 64
 
         # reward torch.Size([4, 5, 64])
-        for t in range(self._unroll_len_add_burnin_step - self._burnin_step - self._nstep):
+        for t in range(self._sequence_len - self._burnin_step - self._nstep):
             # here t=0 means timestep <self._burnin_step> in the original sample sequence, we minus self._nstep
             # because for the last <self._nstep> timestep in the sequence, we don't have their target obs
             td_data = q_nstep_td_data(
                 q_value[t], target_q_value[t], action[t], target_q_action[t], reward[t], done[t], weight[t]
             )
             if self._value_rescale:
-                l, e = q_nstep_td_error_with_rescale_ngu(td_data, self._gamma, self._nstep, value_gamma=value_gamma[t])
+                l, e = q_nstep_td_error_with_rescale(td_data, self._gamma, self._nstep, value_gamma=value_gamma[t])
                 loss.append(l)
                 td_error.append(e.abs())
             else:
-                l, e = q_nstep_td_error_ngu(td_data, self._gamma, self._nstep, value_gamma=value_gamma[t])
+                l, e = q_nstep_td_error(td_data, self._gamma, self._nstep, value_gamma=value_gamma[t])
                 loss.append(l)
                 td_error.append(e.abs())
         loss = sum(loss) / (len(loss) + 1e-8)
@@ -348,7 +355,8 @@ class NGUPolicy(Policy):
         td_error_per_sample = 0.9 * torch.max(
             torch.stack(td_error), dim=0
         )[0] + (1 - 0.9) * (torch.sum(torch.stack(td_error), dim=0) / (len(td_error) + 1e-8))
-        # td_error shape list(<self._unroll_len_add_burnin_step-self._burnin_step-self._nstep>, B), for example, (75,64)
+        # td_error shape list(<self._sequence_len-self._burnin_step-self._nstep>, B),
+        # for example, (75,64)
         # torch.sum(torch.stack(td_error), dim=0) can also be replaced with sum(td_error)
 
         # update
@@ -394,27 +402,35 @@ class NGUPolicy(Policy):
             Collect mode init method. Called by ``self.__init__``.
             Init traj and unroll length, collect model.
         """
+        assert 'unroll_len' not in self._cfg.collect, "ngu use default <unroll_len = learn_unroll_len + burnin_step>"
         self._nstep = self._cfg.nstep
         self._burnin_step = self._cfg.burnin_step
         self._gamma = self._cfg.discount_factor
-        self._unroll_len_add_burnin_step = self._cfg.unroll_len + self._cfg.burnin_step
-        self._unroll_len = self._unroll_len_add_burnin_step  # for compatibility
+        self._sequence_len = self._cfg.learn_unroll_len + self._cfg.burnin_step
+        self._unroll_len = self._sequence_len
         self._collect_model = model_wrap(
             self._model, wrapper_name='hidden_state', state_num=self._cfg.collect.env_num, save_prev_state=True
         )
-        self._collect_model = model_wrap(self._collect_model, wrapper_name='eps_greedy_sample_ngu')
+        self._collect_model = model_wrap(self._collect_model, wrapper_name='eps_greedy_sample')
         self._collect_model.reset()
-        self.index_to_gamma = {
+        self.index_to_gamma = {  # NOTE
             i: 1 - torch.exp(
                 (
                     (self._cfg.collect.env_num - 1 - i) * torch.log(torch.tensor(1 - 0.997)) +
                     i * torch.log(torch.tensor(1 - 0.99))
                 ) / (self._cfg.collect.env_num - 1)
             )
-            for i in range(self._cfg.collect.env_num)  # TODO
+            for i in range(self._cfg.collect.env_num)
         }
+        # NOTE: for NGU policy collect phase
+        self.beta_index = {
+            i: torch.randint(0, self._cfg.collect.env_num, [1])
+            for i in range(self._cfg.collect.env_num)
+        }
+        # epsilon=0.4, alpha=9
+        self.eps = {i: 0.4 ** (1 + 8 * i / (self._cfg.collect.env_num - 1)) for i in range(self._cfg.collect.env_num)}
 
-    def _forward_collect(self, beta: dict, obs: dict, prev_action: dict, prev_reward_e: dict, eps: dict) -> dict:
+    def _forward_collect(self, data: dict) -> dict:
         r"""
         Overview:
             Collect output according to eps_greedy plugin
@@ -425,21 +441,34 @@ class NGUPolicy(Policy):
         Returns:
             - data (:obj:`dict`): The collected data
         """
-        eps = {i: 0.4 ** (1 + 8 * i / (len(obs) - 1)) for i in range(len(obs))}  # epislon=0.4, alpha=9
-        data_id = list(obs.keys())
-        obs = default_collate(list(obs.values()))
-        beta = default_collate(list(beta.values()))
-        prev_action = default_collate(list(prev_action.values()))
-        prev_reward_e = default_collate(list(prev_reward_e.values()))
+        data_id = list(data.keys())
+        data = default_collate(list(data.values()))
+
+        obs = data['obs']
+        prev_action = data['prev_action'].long()
+        prev_reward_extrinsic = data['prev_reward_extrinsic']
+
+        beta_index = default_collate(list(self.beta_index.values()))
+        if len(data_id) != self._cfg.collect.env_num:
+            # in case, some env is in reset state and only return part data
+            beta_index = beta_index[data_id]
+
         if self._cuda:
             obs = to_device(obs, self._device)
-            beta = to_device(beta, self._device)
+            beta_index = to_device(beta_index, self._device)
             prev_action = to_device(prev_action, self._device)
-            prev_reward_e = to_device(prev_reward_e, self._device)
-        data = {'obs': obs, 'beta': beta, 'prev_action': prev_action, 'prev_reward_e': prev_reward_e}
+            prev_reward_extrinsic = to_device(prev_reward_extrinsic, self._device)
+        # TODO(pu): add prev_reward_intrinsic to network input,
+        #  reward uses some kind of embedding instead of 1D value
+        data = {
+            'obs': obs,
+            'prev_action': prev_action,
+            'prev_reward_extrinsic': prev_reward_extrinsic,
+            'beta': beta_index
+        }
         self._collect_model.eval()
         with torch.no_grad():
-            output = self._collect_model.forward(data, data_id=data_id, eps=eps, inference=True)
+            output = self._collect_model.forward(data, data_id=data_id, eps=self.eps, inference=True)
         if self._cuda:
             output = to_device(output, 'cpu')
         output = default_decollate(output)
@@ -447,8 +476,11 @@ class NGUPolicy(Policy):
 
     def _reset_collect(self, data_id: Optional[List[int]] = None) -> None:
         self._collect_model.reset(data_id=data_id)
+        # NOTE: for NGU policy, in collect phase, each episode, we sample a new beta for each env
+        if data_id is not None:
+            self.beta_index[data_id[0]] = torch.randint(0, self._cfg.collect.env_num, [1])
 
-    def _process_transition(self, beta_index: Any, obs: Any, model_output: dict, timestep: namedtuple) -> dict:
+    def _process_transition(self, obs: Any, model_output: dict, timestep: namedtuple, env_id) -> dict:
         r"""
         Overview:
             Generate dict type transition data from inputs.
@@ -462,25 +494,21 @@ class NGUPolicy(Policy):
         """
         if hasattr(timestep, 'null'):
             transition = {
-                'beta': beta_index,
-                'obs': obs,
+                'beta': self.beta_index[env_id],
+                'obs': obs['obs'],  # NOTE: input obs including obs, prev_action, prev_reward_extrinsic
                 'action': model_output['action'],
-                # 'prev_action': model_output['action'],
                 'prev_state': model_output['prev_state'],
                 'reward': timestep.reward,
-                # 'prev_reward_e': timestep.reward,
                 'done': timestep.done,
                 'null': timestep.null,
             }
         else:
             transition = {
-                'beta': beta_index,
-                'obs': obs,
+                'beta': self.beta_index[env_id],
+                'obs': obs['obs'],  # NOTE: input obs including obs, prev_action, prev_reward_extrinsic
                 'action': model_output['action'],
-                # 'prev_action': model_output['action'],
                 'prev_state': model_output['prev_state'],
                 'reward': timestep.reward,
-                # 'prev_reward_e': timestep.reward,
                 'done': timestep.done,
                 'null': False,
             }
@@ -498,7 +526,7 @@ class NGUPolicy(Policy):
             - samples (:obj:`dict`): The training samples generated
         """
         data = get_nstep_return_data(data, self._nstep, gamma=self.index_to_gamma[int(data[0]['beta'])].item())
-        return get_train_sample(data, self._unroll_len_add_burnin_step)
+        return get_train_sample(data, self._sequence_len)
 
     def _init_eval(self) -> None:
         r"""
@@ -509,14 +537,11 @@ class NGUPolicy(Policy):
         self._eval_model = model_wrap(self._model, wrapper_name='hidden_state', state_num=self._cfg.eval.env_num)
         self._eval_model = model_wrap(self._eval_model, wrapper_name='argmax_sample')
         self._eval_model.reset()
+        # NOTE: for NGU policy eval phase
+        # beta_index = 0 -> beta is approximately 0
+        self.beta_index = {i: torch.tensor([0]) for i in range(self._cfg.eval.env_num)}
 
-    def _forward_eval(
-            self,
-            beta: dict,
-            obs: dict,
-            prev_action: dict,
-            prev_reward_e: dict,
-    ) -> dict:
+    def _forward_eval(self, data: dict) -> dict:
         r"""
         Overview:
             Forward function of collect mode, similar to ``self._forward_collect``.
@@ -527,17 +552,32 @@ class NGUPolicy(Policy):
         Returns:
             - output (:obj:`dict`): Dict type data, including at least inferred action according to input obs.
         """
-        data_id = list(obs.keys())
-        obs = default_collate(list(obs.values()))
-        beta = default_collate(list(beta.values()))
-        prev_action = default_collate(list(prev_action.values()))
-        prev_reward_e = default_collate(list(prev_reward_e.values()))
+
+        data_id = list(data.keys())
+        data = default_collate(list(data.values()))
+
+        obs = data['obs']
+        prev_action = data['prev_action'].long()
+        prev_reward_extrinsic = data['prev_reward_extrinsic']
+
+        beta_index = default_collate(list(self.beta_index.values()))
+        if len(data_id) != self._cfg.collect.env_num:
+            # in case, some env is in reset state and only return part data
+            beta_index = beta_index[data_id]
+
         if self._cuda:
             obs = to_device(obs, self._device)
-            beta = to_device(beta, self._device)
+            beta_index = to_device(beta_index, self._device)
             prev_action = to_device(prev_action, self._device)
-            prev_reward_e = to_device(prev_reward_e, self._device)
-        data = {'obs': obs, 'beta': beta, 'prev_action': prev_action, 'prev_reward_e': prev_reward_e}
+            prev_reward_extrinsic = to_device(prev_reward_extrinsic, self._device)
+        # TODO(pu): add prev_reward_intrinsic to network input,
+        #  reward uses some kind of embedding instead of 1D value
+        data = {
+            'obs': obs,
+            'prev_action': prev_action,
+            'prev_reward_extrinsic': prev_reward_extrinsic,
+            'beta': beta_index
+        }
 
         self._eval_model.eval()
         with torch.no_grad():
