@@ -5,7 +5,7 @@ import copy
 import numpy as np
 from torch.distributions import Independent, Normal
 
-from ding.torch_utils import Adam, to_device, unsqueeze
+from ding.torch_utils import Adam, to_device, unsqueeze, ContrastiveLoss
 from ding.rl_utils import ppo_data, ppo_error, ppo_policy_error, ppo_policy_data, get_gae_with_default_last_value, \
     v_nstep_td_data, v_nstep_td_error, get_nstep_return_data, get_train_sample, gae, gae_data, ppo_error_continuous, \
     get_gae
@@ -167,7 +167,7 @@ class PPOPolicy(Policy):
         self._learn_model.train()
 
         for epoch in range(self._cfg.learn.epoch_per_collect):
-            if self._recompute_adv:  # new v network compute new value
+            if self._recompute_adv:  # calculate new value using the new updated value network
                 with torch.no_grad():
                     value = self._learn_model.forward(data['obs'], mode='compute_critic')['value']
                     next_value = self._learn_model.forward(data['next_obs'], mode='compute_critic')['value']
@@ -765,7 +765,7 @@ class PPOOffPolicy(Policy):
             if self._adv_norm:
                 # Normalize advantage in a total train_batch
                 adv = (adv - adv.mean()) / (adv.std() + 1e-8)
-            # Calculate ppo error
+            # Calculate ppo loss
             ppodata = ppo_data(
                 output['logit'], data['logit'], data['action'], output['value'], data['value'], adv, return_,
                 data['weight']
@@ -781,7 +781,7 @@ class PPOOffPolicy(Policy):
                 # Normalize advantage in a total train_batch
                 adv = (adv - adv.mean()) / (adv.std() + 1e-8)
 
-            # Calculate ppo error
+            # Calculate ppo loss
             ppodata = ppo_policy_data(output['logit'], data['logit'], data['action'], adv, data['weight'])
             ppo_policy_loss, ppo_info = ppo_policy_error(ppodata, self._clip_ratio)
             wv, we = self._value_weight, self._entropy_weight
@@ -954,3 +954,282 @@ class PPOOffPolicy(Policy):
         return super()._monitor_vars_learn() + [
             'policy_loss', 'value_loss', 'entropy_loss', 'adv_abs_max', 'approx_kl', 'clipfrac'
         ]
+
+
+@POLICY_REGISTRY.register('ppo_stdim')
+class PPOSTDIMPolicy(PPOPolicy):
+    """
+    Overview:
+        Policy class of on policy version PPO algorithm with ST-DIM auxiliary model.
+    """
+    config = dict(
+        # (str) RL policy register name (refer to function "POLICY_REGISTRY").
+        type='ppo_stdim',
+        # (bool) Whether to use cuda for network.
+        cuda=False,
+        # (bool) Whether the RL algorithm is on-policy or off-policy. (Note: in practice PPO can be off-policy used)
+        on_policy=True,
+        # (bool) Whether to use priority(priority sample, IS weight, update priority)
+        priority=False,
+        # (bool) Whether to use Importance Sampling Weight to correct biased update due to priority.
+        # If True, priority must be True.
+        priority_IS_weight=False,
+        # (bool) Whether to recompurete advantages in each iteration of on-policy PPO
+        recompute_adv=True,
+        # (str) Which kind of action space used in PPOPolicy, ['discrete', 'continuous']
+        action_space='discrete',
+        # (bool) Whether to use nstep return to calculate value target, otherwise, use return = adv + value
+        nstep_return=False,
+        # (bool) Whether to enable multi-agent training, i.e.: MAPPO
+        multi_agent=False,
+        # (bool) Whether to need policy data in process transition
+        transition_with_policy_data=True,
+        aux_model=dict(
+            # (int) the encoding size (of each head) to apply contrastive loss.
+            encode_shape=64,
+            # ([int, int]) the heads number of the obs encoding and next_obs encoding respectively.
+            heads=[1, 1],
+            # (str) the contrastive loss type.
+            loss_type='infonce',
+            # (float) a parameter to adjust the polarity between positive and negative samples.
+            temperature=1.0,
+        ),
+        learn=dict(
+            # (bool) Whether to use multi gpu
+            multi_gpu=False,
+            epoch_per_collect=10,
+            batch_size=64,
+            learning_rate=3e-4,
+            # ==============================================================
+            # The following configs is algorithm-specific
+            # ==============================================================
+            # (float) The loss weight of value network, policy network weight is set to 1
+            value_weight=0.5,
+            # (float) The loss weight of entropy regularization, policy network weight is set to 1
+            entropy_weight=0.0,
+            # (float) PPO clip ratio, defaults to 0.2
+            clip_ratio=0.2,
+            # (bool) Whether to use advantage norm in a whole training batch
+            adv_norm=True,
+            value_norm=True,
+            ppo_param_init=True,
+            grad_clip_type='clip_norm',
+            grad_clip_value=0.5,
+            ignore_done=False,
+        ),
+        collect=dict(
+            # (int) Only one of [n_sample, n_episode] shoule be set
+            # n_sample=64,
+            # (int) Cut trajectories into pieces with length "unroll_len".
+            unroll_len=1,
+            # ==============================================================
+            # The following configs is algorithm-specific
+            # ==============================================================
+            # (float) Reward's future discount factor, aka. gamma.
+            discount_factor=0.99,
+            # (float) GAE lambda factor for the balance of bias and variance(1-step td and mc)
+            gae_lambda=0.95,
+        ),
+        eval=dict(),
+        aux_loss_weight=0.001,
+    )
+
+    def _init_learn(self) -> None:
+        """
+        Overview:
+            Learn mode init method. Called by ``self.__init__``.
+            Init the auxiliary model, its optimizer, and the axuliary loss weight to the main loss.
+        """
+        super()._init_learn()
+        x_size, y_size = self._get_encoding_size()
+        self._aux_model = ContrastiveLoss(x_size, y_size, **self._cfg.aux_model)
+        if self._cuda:
+            self._aux_model.cuda()
+        self._aux_optimizer = Adam(self._aux_model.parameters(), lr=self._cfg.learn.learning_rate)
+        self._aux_loss_weight = self._cfg.aux_loss_weight
+
+    def _get_encoding_size(self):
+        """
+        Overview:
+            Get the input encoding size of the ST-DIM axuiliary model.
+        Returns:
+            - info_dict (:obj:`[Tuple, Tuple]`): The encoding size without the first (Batch) dimension.
+        """
+        obs = self._cfg.model.obs_shape
+        if isinstance(obs, int):
+            obs = [obs]
+        test_data = {
+            "obs": torch.randn(1, *obs),
+            "next_obs": torch.randn(1, *obs),
+        }
+        if self._cuda:
+            test_data = to_device(test_data, self._device)
+        with torch.no_grad():
+            x, y = self._model_encode(test_data)
+        return x.size()[1:], y.size()[1:]
+
+    def _model_encode(self, data):
+        """
+        Overview:
+            Get the encoding of the main model as input for the auxiliary model.
+        Arguments:
+            - data (:obj:`dict`): Dict type data, same as the _forward_learn input.
+        Returns:
+            - (:obj:`Tuple[Tensor]`): the tuple of two tensors to apply contrastive embedding learning.
+                In ST-DIM algorithm, these two variables are the dqn encoding of `obs` and `next_obs`\
+                respectively.
+        """
+        assert hasattr(self._model, "encoder")
+        x = self._model.encoder(data["obs"])
+        y = self._model.encoder(data["next_obs"])
+        return x, y
+
+    def _forward_learn(self, data: Dict[str, Any]) -> Dict[str, Any]:
+        """
+        Overview:
+            Forward and backward function of learn mode.
+        Arguments:
+            - data (:obj:`dict`): Dict type data
+        Returns:
+            - info_dict (:obj:`Dict[str, Any]`):
+              Including current lr, total_loss, policy_loss, value_loss, entropy_loss, \
+                        adv_abs_max, approx_kl, clipfrac
+        """
+        data = default_preprocess_learn(data, ignore_done=self._cfg.learn.ignore_done, use_nstep=False)
+        if self._cuda:
+            data = to_device(data, self._device)
+        # ====================
+        # PPO forward
+        # ====================
+        return_infos = []
+        self._learn_model.train()
+
+        for epoch in range(self._cfg.learn.epoch_per_collect):
+            if self._recompute_adv:  # calculate new value using the new updated value network
+                with torch.no_grad():
+                    value = self._learn_model.forward(data['obs'], mode='compute_critic')['value']
+                    next_value = self._learn_model.forward(data['next_obs'], mode='compute_critic')['value']
+                    if self._value_norm:
+                        value *= self._running_mean_std.std
+                        next_value *= self._running_mean_std.std
+
+                    traj_flag = data.get('traj_flag', None)  # traj_flag indicates termination of trajectory
+                    compute_adv_data = gae_data(value, next_value, data['reward'], data['done'], traj_flag)
+                    data['adv'] = gae(compute_adv_data, self._gamma, self._gae_lambda)
+
+                    unnormalized_returns = value + data['adv']
+
+                    if self._value_norm:
+                        data['value'] = value / self._running_mean_std.std
+                        data['return'] = unnormalized_returns / self._running_mean_std.std
+                        self._running_mean_std.update(unnormalized_returns.cpu().numpy())
+                    else:
+                        data['value'] = value
+                        data['return'] = unnormalized_returns
+
+            else:  # don't recompute adv
+                if self._value_norm:
+                    unnormalized_return = data['adv'] + data['value'] * self._running_mean_std.std
+                    data['return'] = unnormalized_return / self._running_mean_std.std
+                    self._running_mean_std.update(unnormalized_return.cpu().numpy())
+                else:
+                    data['return'] = data['adv'] + data['value']
+
+            for batch in split_data_generator(data, self._cfg.learn.batch_size, shuffle=True):
+                # ======================
+                # Auxiliary model update
+                # ======================
+
+                # RL network encoding
+                # To train the auxiliary network, the gradients of x, y should be 0.
+                with torch.no_grad():
+                    x_no_grad, y_no_grad = self._model_encode(batch)
+                # the forward function of the auxiliary network
+                self._aux_model.train()
+                aux_loss_learn = self._aux_model.forward(x_no_grad, y_no_grad)
+                # the BP process of the auxiliary network
+                self._aux_optimizer.zero_grad()
+                aux_loss_learn.backward()
+                if self._cfg.learn.multi_gpu:
+                    self.sync_gradients(self._aux_model)
+                self._aux_optimizer.step()
+
+                output = self._learn_model.forward(batch['obs'], mode='compute_actor_critic')
+                adv = batch['adv']
+                if self._adv_norm:
+                    # Normalize advantage in a train_batch
+                    adv = (adv - adv.mean()) / (adv.std() + 1e-8)
+
+                # Calculate ppo loss
+                if self._action_space == 'continuous':
+                    ppo_batch = ppo_data(
+                        output['logit'], batch['logit'], batch['action'], output['value'], batch['value'], adv,
+                        batch['return'], batch['weight']
+                    )
+                    ppo_loss, ppo_info = ppo_error_continuous(ppo_batch, self._clip_ratio)
+                elif self._action_space == 'discrete':
+                    ppo_batch = ppo_data(
+                        output['logit'], batch['logit'], batch['action'], output['value'], batch['value'], adv,
+                        batch['return'], batch['weight']
+                    )
+                    ppo_loss, ppo_info = ppo_error(ppo_batch, self._clip_ratio)
+
+                # ======================
+                # Compute auxiliary loss
+                # ======================
+
+                # In total_loss BP, the gradients of x, y are required to update the encoding network.
+                # The auxiliary network won't be updated since the self._optimizer does not contain
+                # its weights.
+                x, y = self._model_encode(data)
+                self._aux_model.eval()
+                aux_loss_eval = self._aux_model.forward(x, y) * self._aux_loss_weight
+
+                wv, we = self._value_weight, self._entropy_weight
+                total_loss = ppo_loss.policy_loss + wv * ppo_loss.value_loss - we * ppo_loss.entropy_loss\
+                    + aux_loss_eval
+
+                self._optimizer.zero_grad()
+                total_loss.backward()
+                self._optimizer.step()
+
+                return_info = {
+                    'cur_lr': self._optimizer.defaults['lr'],
+                    'total_loss': total_loss.item(),
+                    'aux_loss_learn': aux_loss_learn.item(),
+                    'aux_loss_eval': aux_loss_eval.item(),
+                    'policy_loss': ppo_loss.policy_loss.item(),
+                    'value_loss': ppo_loss.value_loss.item(),
+                    'entropy_loss': ppo_loss.entropy_loss.item(),
+                    'adv_max': adv.max().item(),
+                    'adv_mean': adv.mean().item(),
+                    'value_mean': output['value'].mean().item(),
+                    'value_max': output['value'].max().item(),
+                    'approx_kl': ppo_info.approx_kl,
+                    'clipfrac': ppo_info.clipfrac,
+                }
+                if self._action_space == 'continuous':
+                    return_info.update(
+                        {
+                            'act': batch['action'].float().mean().item(),
+                            'mu_mean': output['logit']['mu'].mean().item(),
+                            'sigma_mean': output['logit']['sigma'].mean().item(),
+                        }
+                    )
+                return_infos.append(return_info)
+        return return_infos
+
+    def _state_dict_learn(self) -> Dict[str, Any]:
+        return {
+            'model': self._learn_model.state_dict(),
+            'optimizer': self._optimizer.state_dict(),
+            'aux_optimizer': self._aux_optimizer.state_dict(),
+        }
+
+    def _load_state_dict_learn(self, state_dict: Dict[str, Any]) -> None:
+        self._learn_model.load_state_dict(state_dict['model'])
+        self._optimizer.load_state_dict(state_dict['optimizer'])
+        self._aux_optimizer.load_state_dict(state_dict['aux_optimizer'])
+
+    def _monitor_vars_learn(self) -> List[str]:
+        return super()._monitor_vars_learn() + ["aux_loss_learn", "aux_loss_eval"]
