@@ -69,12 +69,15 @@ class RndRewardModel(BaseRewardModel):
         # means the rescale value of RND intrinsic_reward only used when intrinsic_reward_weight is None
     )
 
-    def __init__(self, config: EasyDict, device: str, tb_logger: 'SummaryWriter') -> None:  # noqa
+    def __init__(self, config: EasyDict, device: str = 'cpu', tb_logger: 'SummaryWriter' = None) -> None:  # noqa
         super(RndRewardModel, self).__init__()
         self.cfg = config
         self.intrinsic_reward_rescale = self.cfg.intrinsic_reward_rescale
         assert device == "cpu" or device.startswith("cuda")
         self.device = device
+        if tb_logger is None:  # TODO
+            from tensorboardX import SummaryWriter
+            tb_logger = SummaryWriter('rnd_reward_model')
         self.tb_logger = tb_logger
         self.reward_model = RndNetwork(config.obs_shape, config.hidden_size_list)
         self.reward_model.to(self.device)
@@ -138,8 +141,8 @@ class RndRewardModel(BaseRewardModel):
 
             rnd_reward = rnd_reward.to(train_data_augmented[0]['reward'].device)
             rnd_reward = torch.chunk(rnd_reward, rnd_reward.shape[0], dim=0)
-        """NOTE:
-        Following normalization approach to extrinsic reward seems be not reasonable,
+        """
+        NOTE: Following normalization approach to extrinsic reward seems be not reasonable,
         because this approach compresses the extrinsic reward magnitude, resulting in less informative reward signals.
         """
         # rewards = torch.stack([data[i]['reward'] for i in range(len(data))])
@@ -147,7 +150,8 @@ class RndRewardModel(BaseRewardModel):
 
         # TODO(pu): how to set intrinsic_reward_rescale automatically?
         if self.cfg.intrinsic_reward_weight is None:
-            """Note: the following way of setting self.cfg.intrinsic_reward_weight is only suitable for the dense
+            """
+            NOTE: the following way of setting self.cfg.intrinsic_reward_weight is only suitable for the dense
             reward env like lunarlander, not suitable for the dense reward env.
             In sparse reward env, e.g. minigrid, if the agent reaches the goal, it obtain reward ~1, otherwise 0.
             Thus, in sparse reward env, it's reasonable to set the intrinsic_reward_weight approximately equal to
