@@ -4,7 +4,7 @@ import torch.nn as nn
 import torch.nn.functional as F
 from torch.nn.init import xavier_normal_, kaiming_normal_, orthogonal_
 from typing import Union, Tuple, List, Callable
-from ding.compatibility import torch_gt_131
+from ding.compatibility import torch_ge_131
 
 from .normalization import build_normalization
 
@@ -246,6 +246,53 @@ def fc_block(
     return sequential_pack(block)
 
 
+def normed_linear(in_features, out_features, bias: bool = True, device=None, dtype=None, scale=1.0):
+    """
+    nn.Linear but with normalized fan-in init
+    """
+
+    out = nn.Linear(in_features, out_features, bias)
+
+    out.weight.data *= scale / out.weight.norm(dim=1, p=2, keepdim=True)
+    if bias:
+        out.bias.data.zero_()
+    return out
+
+
+def normed_conv2d(
+    in_channels,
+    out_channels,
+    kernel_size,
+    stride=1,
+    padding=0,
+    dilation=1,
+    groups=1,
+    bias: bool = True,
+    padding_mode='zeros',
+    device=None,
+    dtype=None,
+    scale=1
+):
+    """
+    nn.Conv2d but with normalized fan-in init
+    """
+    out = nn.Conv2d(
+        in_channels,
+        out_channels,
+        kernel_size,
+        stride,
+        padding,
+        dilation,
+        groups,
+        bias,
+        padding_mode,
+    )
+    out.weight.data *= scale / out.weight.norm(dim=(1, 2, 3), p=2, keepdim=True)
+    if bias:
+        out.bias.data.zero_()
+    return out
+
+
 def MLP(
     in_channels: int,
     hidden_channels: int,
@@ -369,7 +416,7 @@ def one_hot(val: torch.LongTensor, num: int, num_first: bool = False) -> torch.F
     # If the value is -1, then it should be converted to all zeros encodings and
     # the corresponding entry in index_neg_one is 1, which is used to transform
     # the ret after the operation of ret.scatter_(1, val_reshape, 1) to their correct encodings bellowing
-    index_neg_one = torch.eq(val_reshape, -1).long()
+    index_neg_one = torch.eq(val_reshape, -1).float()
     if index_neg_one.sum() != 0:  # if -1 exists in val
         # convert the original value -1 to 0
         val_reshape = torch.where(
@@ -601,7 +648,7 @@ class NaiveFlatten(nn.Module):
             return x.view(*x.shape[:self.start_dim], -1)
 
 
-if torch_gt_131():
+if torch_ge_131():
     Flatten = nn.Flatten
 else:
     Flatten = NaiveFlatten
