@@ -1,5 +1,3 @@
-import numpy as np
-import matplotlib as mpl
 import matplotlib.pyplot as plt
 import seaborn as sns
 
