@@ -6,14 +6,21 @@ import torch
 from torch import nn
 
 from scipy.spatial import KDTree
+from functools import partial
 from ding.utils import WORLD_MODEL_REGISTRY
 from ding.utils.data import default_collate
+from ding.torch_utils import unsqueeze_repeat
 from ding.world_model.base_world_model import HybridWorldModel
 from ding.world_model.model.ensemble import EnsembleModel, StandardScaler
 
 
 #======================= Helper functions =======================
-def get_neighbor_index(data, k):
+# tree_query = lambda datapoint: tree.query(datapoint, k=k+1)[1][1:]
+def tree_query(datapoint, tree, k):
+    return tree.query(datapoint, k=k + 1)[1][1:]
+
+
+def get_neighbor_index(data, k, serial=False):
     """
         data: [B, N]
         k: int
@@ -22,16 +29,16 @@ def get_neighbor_index(data, k):
     """
     data = data.cpu().numpy()
     tree = KDTree(data)
-    global tree_query
 
-    # tree_query = lambda datapoint: tree.query(datapoint, k=k+1)[1][1:]
-    def tree_query(datapoint):
-        return tree.query(datapoint, k=k + 1)[1][1:]
-
-    # TODO: multiprocessing
-    pool = multiprocessing.Pool(processes=multiprocessing.cpu_count())
-    nn_index = torch.from_numpy(np.array(list(pool.map(tree_query, data)), dtype=np.int32)).to(torch.long)
-    pool.close()
+    if serial:
+        nn_index = [torch.from_numpy(np.array(tree_query(d, tree, k))) for d in data]
+        nn_index = torch.stack(nn_index).long()
+    else:
+        # TODO: speed up multiprocessing
+        pool = multiprocessing.Pool(processes=multiprocessing.cpu_count())
+        fn = partial(tree_query, tree=tree, k=k)
+        nn_index = torch.from_numpy(np.array(list(pool.map(fn, data)), dtype=np.int32)).to(torch.long)
+        pool.close()
     return nn_index
 
 
@@ -137,6 +144,7 @@ class DDPPOWorldMode(HybridWorldModel, nn.Module):
         self.elite_model_idxes_gradient_model = []
 
         self.last_train_step_gradient_model = 0
+        self.serial_calc_nn = False
 
         if self._cuda:
             self.cuda()
@@ -150,7 +158,7 @@ class DDPPOWorldMode(HybridWorldModel, nn.Module):
             def forward(ctx, x):
                 ctx.save_for_backward(x)
                 mean, var = self.rollout_model(x, ret_log_var=False)
-                return torch.concat([mean, var], dim=-1)
+                return torch.cat([mean, var], dim=-1)
 
             @staticmethod
             def backward(ctx, grad_out):
@@ -159,7 +167,7 @@ class DDPPOWorldMode(HybridWorldModel, nn.Module):
                     x = x.detach()
                     x.requires_grad_(True)
                     mean, var = self.gradient_model(x, ret_log_var=False)
-                    y = torch.concat([mean, var], dim=-1)
+                    y = torch.cat([mean, var], dim=-1)
                     return torch.autograd.grad(y, x, grad_outputs=grad_out, create_graph=True)
 
         if len(act.shape) == 1:
@@ -172,7 +180,7 @@ class DDPPOWorldMode(HybridWorldModel, nn.Module):
         # predict
         ensemble_mean, ensemble_var = [], []
         for i in range(0, inputs.shape[0], batch_size):
-            input = inputs[i:i + batch_size].unsqueeze(0).repeat(self.ensemble_size, 1, 1)
+            input = unsqueeze_repeat(inputs[i:i + batch_size], self.ensemble_size)
             if not torch.is_grad_enabled() or not self.gradient_model:
                 b_mean, b_var = self.rollout_model(input, ret_log_var=False)
             else:
@@ -194,7 +202,7 @@ class DDPPOWorldMode(HybridWorldModel, nn.Module):
         model_idxes = torch.from_numpy(np.random.choice(self.elite_model_idxes, size=len(obs))).to(inputs.device)
         batch_idxes = torch.arange(len(obs)).to(inputs.device)
         sample = ensemble_sample[model_idxes, batch_idxes]
-        rewards, next_obs = sample[:, :1], sample[:, 1:]
+        rewards, next_obs = sample[:, 0], sample[:, 1:]
 
         return rewards, next_obs, self.env.termination_fn(next_obs)
 
@@ -223,8 +231,8 @@ class DDPPOWorldMode(HybridWorldModel, nn.Module):
         inputs = self.scaler.transform(inputs)
 
         # repeat for ensemble
-        inputs = inputs.unsqueeze(0).repeat(self.ensemble_size, 1, 1)
-        labels = labels.unsqueeze(0).repeat(self.ensemble_size, 1, 1)
+        inputs = unsqueeze_repeat(inputs, self.ensemble_size)
+        labels = unsqueeze_repeat(labels, self.ensemble_size)
 
         # eval
         with torch.no_grad():
@@ -294,8 +302,8 @@ class DDPPOWorldMode(HybridWorldModel, nn.Module):
         holdout_inputs = self.scaler.transform(holdout_inputs)
 
         #repeat for ensemble
-        holdout_inputs = holdout_inputs.unsqueeze(0).repeat(self.ensemble_size, 1, 1)
-        holdout_labels = holdout_labels.unsqueeze(0).repeat(self.ensemble_size, 1, 1)
+        holdout_inputs = unsqueeze_repeat(holdout_inputs, self.ensemble_size)
+        holdout_labels = unsqueeze_repeat(holdout_labels, self.ensemble_size)
 
         self._epochs_since_update = 0
         self._snapshots = {i: (-1, 1e10) for i in range(self.ensemble_size)}
@@ -384,13 +392,13 @@ class DDPPOWorldMode(HybridWorldModel, nn.Module):
         holdout_inputs = self.scaler.transform(holdout_inputs)
 
         #repeat for ensemble
-        holdout_inputs = holdout_inputs.unsqueeze(0).repeat(self.ensemble_size, 1, 1)
-        holdout_labels = holdout_labels.unsqueeze(0).repeat(self.ensemble_size, 1, 1)
+        holdout_inputs = unsqueeze_repeat(holdout_inputs, self.ensemble_size)
+        holdout_labels = unsqueeze_repeat(holdout_labels, self.ensemble_size)
 
         #no split and normalization on regulation data
         train_inputs_reg, train_labels_reg = inputs_reg, labels_reg
 
-        neighbor_index = get_neighbor_index(train_inputs_reg, self.k)
+        neighbor_index = get_neighbor_index(train_inputs_reg, self.k, serial=self.serial_calc_nn)
         neighbor_inputs = train_inputs_reg[neighbor_index]  # [N, k, state_size+action_size]
         neighbor_labels = train_labels_reg[neighbor_index]  # [N, k, state_size+reward_size]
         neighbor_inputs_distance = (neighbor_inputs - train_inputs_reg.unsqueeze(1))  # [N, k, state_size+action_size]
