@@ -8,13 +8,17 @@ spaceinvaders_dqn_config = dict(
         evaluator_env_num=8,
         n_evaluator_episode=8,
         stop_value=10000000000,
-        env_id='SpaceInvadersNoFrameskip-v4',
+        env_id='SpaceInvaders-v4',
+        #'ALE/SpaceInvaders-v5' is available. But special setting is needed after gym make.
         frame_stack=4,
-        manager=dict(shared_memory=False, )
+        manager=dict(shared_memory=False, ),
+        # The path to save the game replay
+        replay_path='./spaceinvaders_dqn_seed0/video',
     ),
     policy=dict(
         cuda=True,
         priority=False,
+        load_path="./spaceinvaders_dqn_seed0/ckpt/ckpt_best.pth.tar",
         model=dict(
             obs_shape=[4, 84, 84],
             action_shape=6,
