@@ -1,6 +1,7 @@
 from easydict import EasyDict
 
 cartpole_rainbow_config = dict(
+    exp_name='cartpole_rainbow_seed0',
     env=dict(
         collector_env_num=8,
         evaluator_env_num=5,
@@ -49,3 +50,8 @@ cartpole_rainbow_create_config = dict(
 )
 cartpole_rainbow_create_config = EasyDict(cartpole_rainbow_create_config)
 create_config = cartpole_rainbow_create_config
+
+if __name__ == "__main__":
+    # or you can enter `ding -m serial -c cartpole_rainbow_config.py -s 0`
+    from ding.entry import serial_pipeline
+    serial_pipeline((main_config, create_config), seed=0)
