@@ -2,6 +2,7 @@ from easydict import EasyDict
 
 update_per_collect = 8
 cartpole_sqn_config = dict(
+    exp_name='cartpole_sqn_seed0',
     env=dict(
         collector_env_num=8,
         evaluator_env_num=5,
@@ -53,3 +54,8 @@ cartpole_sqn_create_config = dict(
 )
 cartpole_sqn_create_config = EasyDict(cartpole_sqn_create_config)
 create_config = cartpole_sqn_create_config
+
+if __name__ == "__main__":
+    # or you can enter `ding -m serial -c cartpole_sqn_config.py -s 0`
+    from ding.entry import serial_pipeline
+    serial_pipeline((main_config, create_config), seed=0)
