@@ -12,21 +12,24 @@ class TestCartPoleEnv:
         assert env._seed == 314
         obs = env.reset()
         assert obs.shape == (4, )
-        act_val = env.info().act_space.value
-        min_val, max_val = act_val['min'], act_val['max']
         for _ in range(5):
             env.reset()
             np.random.seed(314)
             print('=' * 60)
             for i in range(10):
-                random_action = np.random.randint(min_val, max_val, size=(1, ))
+                # Both ``env.random_action()``, and utilizing ``np.random`` as well as action space,
+                # can generate legal random action.
+                if i < 5:
+                    random_action = np.array([env.action_space.sample()])
+                else:
+                    random_action = env.random_action()
                 timestep = env.step(random_action)
                 print(timestep)
                 assert isinstance(timestep.obs, np.ndarray)
                 assert isinstance(timestep.done, bool)
                 assert timestep.obs.shape == (4, )
                 assert timestep.reward.shape == (1, )
-                assert timestep.reward >= env.info().rew_space.value['min']
-                assert timestep.reward <= env.info().rew_space.value['max']
-        print(env.info())
+                assert timestep.reward >= env.reward_space.low
+                assert timestep.reward <= env.reward_space.high
+        print(env.observation_space, env.action_space, env.reward_space)
         env.close()
