@@ -1,7 +1,7 @@
 from easydict import EasyDict
 
 pendulum_td3_bc_config = dict(
-    exp_name='pendulum_td3_bc',
+    exp_name='pendulum_td3_bc_seed0',
     env=dict(
         collector_env_num=8,
         evaluator_env_num=5,
@@ -65,3 +65,8 @@ pendulum_td3_bc_create_config = dict(
 )
 pendulum_td3_bc_create_config = EasyDict(pendulum_td3_bc_create_config)
 create_config = pendulum_td3_bc_create_config
+
+if __name__ == "__main__":
+    # or you can enter `ding -m serial_offline -c pendulum_td3_bc_config.py -s 0`
+    from ding.entry import serial_pipeline_offline
+    serial_pipeline_offline([main_config, create_config], seed=0)
