@@ -14,20 +14,30 @@ class PendulumEnv(BaseEnv):
     def __init__(self, cfg: dict) -> None:
         self._cfg = cfg
         self._act_scale = cfg.act_scale
-        self._env = gym.make('Pendulum-v0')
+        self._env = gym.make('Pendulum-v1')
         self._init_flag = False
         self._replay_path = None
+        if 'continuous' in cfg.keys():
+            self._continuous = cfg.continuous
+        else:
+            self._continuous = True
         self._observation_space = gym.spaces.Box(
             low=np.array([-1.0, -1.0, -8.0]), high=np.array([1.0, 1.0, 8.0]), shape=(3, ), dtype=np.float32
         )
-        self._action_space = gym.spaces.Box(low=-2.0, high=2.0, shape=(1, ), dtype=np.float32)
+        if self._continuous:
+            self._action_space = gym.spaces.Box(
+                low=-2.0, high=2.0, shape=(1, ), dtype=np.float32)
+        else:
+            self._discrete_action_num = 11
+            self._action_space = gym.spaces.Discrete(self._discrete_action_num)
+        self._action_space.seed(0)  # default seed
         self._reward_space = gym.spaces.Box(
             low=-1 * (3.14 * 3.14 + 0.1 * 8 * 8 + 0.001 * 2 * 2), high=0.0, shape=(1, ), dtype=np.float32
         )
 
     def reset(self) -> np.ndarray:
         if not self._init_flag:
-            self._env = gym.make('Pendulum-v0')
+            self._env = gym.make('Pendulum-v1')
             if self._replay_path is not None:
                 self._env = gym.wrappers.RecordVideo(
                     self._env,
@@ -39,8 +49,10 @@ class PendulumEnv(BaseEnv):
         if hasattr(self, '_seed') and hasattr(self, '_dynamic_seed') and self._dynamic_seed:
             np_seed = 100 * np.random.randint(1, 1000)
             self._env.seed(self._seed + np_seed)
+            self._action_space.seed(self._seed + np_seed)
         elif hasattr(self, '_seed'):
             self._env.seed(self._seed)
+            self._action_space.seed(self._seed)
         obs = self._env.reset()
         obs = to_ndarray(obs).astype(np.float32)
         self._final_eval_reward = 0.
@@ -58,12 +70,18 @@ class PendulumEnv(BaseEnv):
 
     def step(self, action: np.ndarray) -> BaseEnvTimestep:
         assert isinstance(action, np.ndarray), type(action)
+        # if require discrete env, convert actions to [-1 ~ 1] float actions
+        if not self._continuous:
+            action = (action / (self._discrete_action_num-1)) * 2 - 1
+        # scale into [-2, 2]
         if self._act_scale:
-            action = affine_transform(action, min_val=self._env.action_space.low, max_val=self._env.action_space.high)
+            action = affine_transform(
+                action, min_val=self._env.action_space.low, max_val=self._env.action_space.high)
         obs, rew, done, info = self._env.step(action)
         self._final_eval_reward += rew
         obs = to_ndarray(obs).astype(np.float32)
-        rew = to_ndarray([rew]).astype(np.float32)  # wrapped to be transfered to a array with shape (1,)
+        # wrapped to be transfered to a array with shape (1,)
+        rew = to_ndarray([rew]).astype(np.float32)
         if done:
             info['final_eval_reward'] = self._final_eval_reward
         return BaseEnvTimestep(obs, rew, done, info)
@@ -74,7 +92,13 @@ class PendulumEnv(BaseEnv):
         self._replay_path = replay_path
 
     def random_action(self) -> np.ndarray:
-        return self.action_space.sample().astype(np.float32)
+        # consider discrete
+        if self._continuous:
+            random_action = self.action_space.sample().astype(np.float32)
+        else:
+            random_action = self.action_space.sample()
+            random_action = to_ndarray([random_action], dtype=np.int64)
+        return random_action
 
     @property
     def observation_space(self) -> gym.spaces.Space:
