@@ -13,6 +13,7 @@ main_config = dict(
         n_landmark=n_landmark,
         max_cycles=100,
         agent_obs_only=False,
+        agent_specific_global_state=True,
         continuous_actions=False,
         collector_env_num=collector_env_num,
         evaluator_env_num=evaluator_env_num,
@@ -27,7 +28,7 @@ main_config = dict(
             action_space='discrete',
             agent_num=n_agent,
             agent_obs_shape=2 + 2 + n_landmark * 2 + (n_agent - 1) * 2 + (n_agent - 1) * 2,
-            global_obs_shape=n_agent * 4 + n_landmark * 2 + n_agent * (n_agent - 1) * 2,
+            global_obs_shape=2 + 2 + n_landmark * 2 + (n_agent - 1) * 2 + (n_agent - 1) * 2 + n_agent * (2 + 2) + n_landmark * 2 + n_agent * (n_agent - 1) * 2,
             action_shape=5,
         ),
         learn=dict(
