@@ -57,7 +57,7 @@ create_config = dict(
         import_names=['dizoo.petting_zoo.envs.petting_zoo_env'],
         type='petting_zoo',
     ),
-    env_manager=dict(type='subprocess'),
+    env_manager=dict(type='base'),
     policy=dict(type='qmix'),
 )
 create_config = EasyDict(create_config)
@@ -68,4 +68,4 @@ ptz_simple_spread_qmix_create_config = create_config
 if __name__ == '__main__':
     # or you can enter `ding -m serial -c ptz_simple_spread_qmix_config.py -s 0`
     from ding.entry import serial_pipeline
-    serial_pipeline((main_config, create_config), seed=0)
\ No newline at end of file
+    serial_pipeline((main_config, create_config), seed=0)
