@@ -1,6 +1,6 @@
 import gym
 import numpy as np
-import logging
+from ditk import logging
 
 from ding.envs import ObsNormWrapper, RewardNormWrapper
 
